@@ -6,7 +6,7 @@
 #
 gmt begin ex01
 	gmt subplot begin 2x1 -A -M0.5c -Blrtb -Bafg -T"Low Order Geoid" -Fs16c/0 -Rg -JH16c
-		gmt coast -JH? -Glightbrown -Slightblue -c0,0
+		gmt coast -JH180/? -Glightbrown -Slightblue -c0,0
 		gmt grdcontour @osu91a1f_16.nc -C10 -A50+f7p -Gd10c -Ln -Wcthinnest,- -Wathin,- -T+d8p/2p+l
 		gmt grdcontour @osu91a1f_16.nc -C10 -A50+f7p -Gd10c -LP -T+d8p/2p+l
 
